summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--django/core/management.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/django/core/management.py b/django/core/management.py
index eccd356ad7..2276c6efe1 100644
--- a/django/core/management.py
+++ b/django/core/management.py
@@ -45,8 +45,8 @@ def disable_termcolors():
global style
style = dummy()
-# Disable terminal coloring on Windows or if somebody's piping the output.
-if sys.platform == 'win32' or not sys.stdout.isatty():
+# Disable terminal coloring on Windows, Pocket PC, or if somebody's piping the output.
+if sys.platform == 'win32' or sys.platform == 'Pocket PC' or not sys.stdout.isatty():
disable_termcolors()
def _is_valid_dir_name(s):